#!/usr/bin/env python3

################################################################################
#
# Copyright (c) 2020, Perforce Software, Inc.  All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1.  Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#
# 2.  Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL PERFORCE SOFTWARE, INC. BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# DATE
#   
#   $Date: 2020/04/02 $
#
# SYNOPSIS
# 
#   BOMDetection.py file
#
# DESCRIPTION
#
#   This script checks for any UTF8 BOM in file
#   It is intended to be against a list of server depot file of utf8 filetype
#   which be encoded in UTF8 no BOM
#   Example of command to be run on the server itself:
#   p4 -F%lbrPath% fstat -Obf -F headType=*utf8* //... | python BOMDetection.py
#   (the above -Ob flag requires a 2017.2 or higher server)
#
################################################################################

from __future__ import print_function
import sys
import re

def main():
    if len(sys.argv) > 1:
       sys.exit("stdin argument only, see script header") 
    else:
       for file in sys.stdin:
           filename = file.splitlines()[0]
           for line in open(filename, "rb"):
               if re.search(b"\xEF\xBB\xBF", line):
                  print("UTF8 BOM detected in " + filename)
                  break

if __name__ == '__main__':
    main()
